;; Generated package description from plz.el  -*- no-byte-compile: t -*-
(define-package "plz" "0.7.3" "HTTP library" '((emacs "26.3")) :commit "1b66fa907d6dbc64c6a01b96d58261f67a09200e" :authors '(("Adam Porter" . "adam@alphapapa.net")) :maintainer '("Adam Porter" . "adam@alphapapa.net") :keywords '("comm" "network" "http") :url "https://github.com/alphapapa/plz.el")
